@@ -1,9 +1,11 @@
-from . import variable, elementary_functions, forward
+from . import variable, elementary_functions, forward, reverse
 
 from .variable import *
 from .elementary_functions import *
 from .forward import *
+from .reverse import *
 
 __all__ = (variable.__all__ +
            elementary_functions.__all__ +
-           forward.__all__)
\ No newline at end of file
+           forward.__all__ +
+           reverse.__all__)
\ No newline at end of file
